@@ -6,7 +6,7 @@ from django.db.models.functions import Cast
 
 from .orm_fields import OrmBaseField, OrmBoundField
 from .types import BooleanType, DateTimeType, DateType, DurationType, NumberType
-from .util import s
+from .util import annotation_path, s
 
 _TYPE_AGGREGATES = defaultdict(
     lambda: [("count", NumberType)],
@@ -80,12 +80,13 @@ class OrmAggregateField(OrmBaseField):
 
     def bind(self, previous):
         assert previous
-        queryset_path = previous.queryset_path + [self.name]
+        full_path = previous.full_path + [self.name]
+        queryset_path = annotation_path(full_path)
         agg_func = _get_django_aggregate(previous.type_, self.name)
         return OrmBoundField(
             field=self,
             previous=previous,
-            full_path=previous.full_path + [self.name],
+            full_path=full_path,
             pretty_path=previous.pretty_path + [self.pretty_name],
             queryset_path=queryset_path,
             aggregate_clause=(s(queryset_path), agg_func(s(previous.queryset_path))),
