@@ -87,6 +87,7 @@ class OrmBaseField:
     default_sort: str = None
     format_hints: dict = None
     actions: dict = None
+    to_many: bool = False
 
     def __post_init__(self):
         if not self.type_:
@@ -110,8 +111,10 @@ class OrmBaseField:
 
 
 class OrmFkField(OrmBaseField):
-    def __init__(self, model_name, name, pretty_name, rel_name):
-        super().__init__(model_name, name, pretty_name, rel_name=rel_name)
+    def __init__(self, model_name, name, pretty_name, rel_name, to_many):
+        super().__init__(
+            model_name, name, pretty_name, rel_name=rel_name, to_many=to_many
+        )
 
     def bind(self, previous):
         previous = previous or OrmBoundField.blank()
@@ -277,3 +280,24 @@ class OrmFileField(OrmConcreteField):
                 return str(e)
 
         return format
+
+
+class OrmURLField(OrmConcreteField):
+    def __init__(self, model_name, name, pretty_name, django_field):
+        super().__init__(
+            model_name,
+            name,
+            pretty_name,
+            type_=HTMLType,
+            rel_name=HTMLType.name,
+            choices=None,
+        )
+        self.django_field = django_field
+
+    def get_formatter(self):
+        def format(value):
+            if not value:
+                return value
+            return format_html('<a href="{}">{}</a>', value, value)
+
+        return format
